function BladeLeaning
disp('BladeLeaning')

global e saved f
intstep=saved.sl;   %saved.sl=number of streamlines.
e.BLLine=func_BezierCurve(e.BLpoint, intstep);   % same number of points as streamlines
set(gcf,'CurrentAxes',e.BladeLeaningFig);
set(gcf,'WindowButtonUpFcn',@stopdragfcnradial);
try delete (e.BLLinePlot);end
e.BLLinePlot=plot(e.BLLine(:,1),e.BLLine(:,2),'-k');  % plotting the bezier curve
try delete (e.BLPointPlot);end
e.BLPointPlot=plot(e.BLpoint(:,1),e.BLpoint(:,2),'marker','s','markersize',5,'markerfacecolor','c','linestyle','none');
set(e.BLPointPlot,'ButtonDownFcn',{@startdragfcnradial});
%--------------------------------------------------------------------------
% Including blade leaning
%--------------------------------------------------------------------------
e.deltaBL=e.BLLine(:,1)*pi/180;
%--------------------------------------------------------------------------
% Including blade leaning gradient
%--------------------------------------------------------------------------
% BLGradx=[1 0.45 0.1];
% BLGrady=[1 0.5 0];
% int=saved.p-1;
% BLxint=zeros(saved.p,1);
% BLyint=BLxint;
% BLx=linspace(BLGradx(1),BLGradx(end),int);
% BLy=interp1(BLGradx,BLGrady,BLx);
% BLyint(1:end-1)=BLy';
% e.Theta=zeros(size(saved.Rmat));
% for b=1:saved.sl
%     e.Theta(:,b)=e.Theta_0(:,b)+e.deltaBL(b).*BLyint;   %keep trailing edge fixed. linear increase in rotation.
% %     e.Theta(:,b)=e.Theta_0(:,b)+e.deltaBL(b); %Rotate around runner axis of rotation
% end

%--------------------------------------------------------------------------
% Including blade leaning gradient
%--------------------------------------------------------------------------
e.Theta = zeros(size(e.Theta_0));
[Point, Line] = size(e.Theta_0);
e.LeaningOption=get(e.LeaningCheck,'Value');
if e.LeaningOption == 0
    for b=1:saved.sl
%         e.Theta(:,b)=e.Theta_0(:,b)+e.deltaBL(b).*BLyint;   %keep trailing edge fixed. linear increase in rotation.
        e.Theta(:,b)=e.Theta_0(:,b)+e.deltaBL(b); %Rotate around runner axis of rotation
    end
else
    for i=1:Line
        for j=1:Point-1
            e.delta_theta(j,i) = 1-(saved.Rmat(1,i)-saved.Rmat(j,i))/(saved.Rmat(1,i)-saved.Rmat(end-1,i));
            e.Theta(j,i)=e.Theta_0(j,i)+e.delta_theta(j,i)*e.deltaBL(i,1);
        end
    end
    e.Theta(end,:)=e.Theta_0(end,:);
end
%--------------------------------------------------------------------------
% Plotting the radial view
%--------------------------------------------------------------------------
set(gcf,'CurrentAxes',e.RadialFig);
try delete(e.RadialPlot); end
e.RadialPlot=polar(e.Theta,saved.Rmat,'k-');
%--------------------------------------------------------------------------
% Calculating the cartesian coordinates from the Radial View
%--------------------------------------------------------------------------
e.Xmat=saved.Rmat.*cos(e.Theta);
e.Ymat=saved.Rmat.*sin(e.Theta);
%--------------------------------------------------------------------------
% Finding the radius of curvature using the surfature function
% [surfature function is from Matlab file exchange, but slightly modified]
%--------------------------------------------------------------------------
e.curv=surfature(e.Xmat,e.Ymat,saved.Zmat);
%--------------------------------------------------------------------------
% Finding the area of each section area on the blade. This function migh
% need to be revised.
%--------------------------------------------------------------------------
e.erosionarea=erosionarea(e.Xmat,e.Ymat,saved.Zmat);
const=1;
e.erosion=saved.Wmat.^3*const;
e.erosiontotal=sum(sum(e.erosion.*e.erosionarea))/sum(sum(e.erosionarea));
e.erosionref=41467.9128; % e.erosiontotal of reference design
e.erosion_factor=e.erosiontotal/e.erosionref;
set(e.erosionfactornumber,'string',num2str(e.erosion_factor));
%--------------------------------------------------------------------------
% Calcultaing the required number of blades to avoid bacflow at the inlet on
% the pressure side of the blade at part load, as W is less. Might need to
% be revised, as results seem somewhat conservative.
%--------------------------------------------------------------------------
e.CmMatPL=0.8.*saved.c_mMat;
e.WmatPL=((f.Umat-f.Cumat).^2+e.CmMatPL.^2).^(1/2);
e.dwdn=-2*saved.omega-e.WmatPL.*e.curv;
e.O=(2*pi).*saved.Rmat;
e.deltan_max=-(e.WmatPL./e.dwdn);
e.Z_r=e.O./(2.*e.deltan_max);
e.maxZ_r=ceil(max(max(e.Z_r(:,:))));
set(e.NoBlades,'String',num2str(e.maxZ_r));
if saved.nobladesindex==0
    td = exist('Zrc.mat');
    if td == 2;
        load('Zrc.mat')
        e.Z_rc = Zrc;
        set(e.NoBladesEdit,'String',num2str(Zrc));

    else
        e.Z_rc = e.maxZ_r;
        set(e.NoBladesEdit,'String',num2str(e.Z_rc));     

    end
    saved.nobladesindex=1;
end
%--------------------------------------------------------------------------
% Plotting the 3D shape of the blade, Switch on chosen colormap of blade
%--------------------------------------------------------------------------
plotBG_3D
plotUCu3D
end
function startdragfcnradial(~,~)
disp('startdragfcnradial')
global e
y=get(gca,'CurrentPoint');
y=min(y,max(e.BLpoint(:,2)));
y=max(y,min(e.BLpoint(:,2)));
index=interp1(e.BLpoint(:,2),1:size(e.BLpoint,1),y(1,2),'nearest');
set(gcf,'WindowButtonMotionFcn',{@draggingfcnradial,index});
end

function draggingfcnradial(~,~,index)
disp('draggingfcnradial')
global e saved
e.drag=1;
pt=get(gca,'CurrentPoint');
newx=get(e.BLPointPlot,'XData');
newx(1,index)=pt(1,1);
newy=get(e.BLPointPlot,'YData');
if index==2;
    newy(1,index)=pt(1,2);
end
e.temp(:,1)=newx';
e.temp(:,2)=newy';
set(e.BLPointPlot,'XData',newx);
set(e.BLPointPlot,'YData',newy);
% Resets the Blade thickness distribution
saved.bt=0;
end
function stopdragfcnradial(~,~)
disp('stopdragfcnradialBL')
global e
if e.drag==1
    e.drag=0;
    e.BLpoint=e.temp;
    set(gcf,'WindowButtonMotionFcn','');
    BladeLeaning
end
end