function CheckValues
disp('CheckValues')

global c h main saved
%--------------------------------------------------------------------------
% Get head, flow rate and nominal flow rate
%--------------------------------------------------------------------------
h.H=str2double(get(h.HeadEdit,'String'));
h.Q=str2double(get(h.FlowEdit,'String'));
h.Qn=h.Q*1.2;                                                                %nominal flow (flow at full load)
red=sqrt(2*main.grav*h.H); %Reduction factor for reduced velocities
%--------------------------------------------------------------------------
% Calculating outlet dimensions, ! note calculation of outlet area and outlet angle
% beta_2
%--------------------------------------------------------------------------
if h.first == 0
    td = exist('Thickness.mat');
    if td == 2;
        load('Thickness.mat');
        t_te = Ttrail/1000; %trailing edge  %Using data from last run
        t_le = Tlead/1000; %leading edge
    else
        t_te=0.008; %trailing edge                                              %Guessing, do control estimations
        t_le=0.015; %leading edge
    end
    Z_b=17; %Number of runner blades
else
    t_te = c.ttrailing/1000;
    t_le = c.tleading/1000;
    Z_b = c.Z_b;
end

h.Z_p1=str2double(get(h.ZpEdit,'String'));
n=3000/h.Z_p1;  %h.Z_p1 = number of pole pairs     
h.omega=n*pi/30; 
h.D_2=str2double(get(h.D2Edit,'String'));
h.U_2=pi*n*h.D_2/60;
beta_2guess=0;
beta_2real=90;
while abs(beta_2guess-beta_2real)>0.1
    beta_2guess=beta_2real;
    t_long=t_te/sind(beta_2guess);  
    t_short=t_te*cosd(beta_2guess)/(3*tand(beta_2guess));   % Ekstra tykkelse pga vinkel
    h.A_2=pi*h.D_2^2/4- Z_b*h.D_2/2*(t_te+((t_long-t_short)-t_te)/2); 
    h.c_m2=h.Q/h.A_2;
    beta_2real=atand(h.c_m2/h.U_2);
end
h.beta_2=beta_2real;
clear beta_2real; clear beta_2guess;
h.w_2=sqrt(h.c_m2^2+h.U_2^2);  
h.w_2red=h.w_2/red;
h.u_2red=h.U_2/red;
h.c_m2red=h.c_m2/red;
%--------------------------------------------------------------------------
% Calculating submergence, negative value of Hs implies a turbine setting
% below tail water level
%--------------------------------------------------------------------------
a=1.12; be=0.055;
h_b=10.3;
h_va=0.125;
c_m2npsh=4*h.Qn/(pi*h.D_2^2);                   
NPSH_t= a*(c_m2npsh)^2/(2*main.grav)+be*h.U_2^2/(2*main.grav);
h.Hs=h_b-h_va-NPSH_t;
%--------------------------------------------------------------------------
% Calculating inlet dimensions
%--------------------------------------------------------------------------
h.B_1=str2double(get(h.B1Edit,'String'));
h.u_1red = get(h.U1redSlider,'Value');
h.u_1=h.u_1red*red;
h.D_1 = h.u_1*60*2/(n*2*pi);
h.A_1 = pi*(h.D_1-Z_b*t_le)*h.B_1;                                     %Assumption: t_le*sin(beta_1) ~ t_le
h.c_m1 = h.c_m2*h.A_2/h.A_1; %continuity
h.c_m1red = h.c_m1/red;
h.acc = (h.c_m2/h.c_m1-1)*100; %acceleration
%h.U_2 = h.u_1*h.D_2/h.D_1; %periferal velocity

h.c_u1red=main.etah/(2*h.u_1red);
h.c_u1=h.c_u1red*red;
h.c_1=sqrt(h.c_u1^2+h.c_m1^2);
h.c_1red=h.c_1/red;
h.alpha=atand(h.c_m1/h.c_u1);
h.w_u1=h.u_1-h.c_u1;
h.w_u1red=h.w_u1/red;
h.w_1=sqrt(h.c_m1^2+h.w_u1^2);
h.w_1red=h.w_1/red;
if h.w_u1 > 0
    h.beta_1=atand(h.c_m1/h.w_u1);
else
    h.beta_1=180+atand(h.c_m1/h.w_u1);
end
%h.B_1=h.Q/(h.c_m1*(pi*h.D_1-Z_b*t_le/sind(h.beta_1)));                      %B1 er kjenr, beregn aksel istedet (normalt 10-20%)
%--------------------------------------------------------------------------
% Calculating power, torque, speed number and reaction ratio
%--------------------------------------------------------------------------
P=round(main.etah*main.rho*main.grav*h.Q*h.H/10000)/100; %[MW]
h.power=P*1*10^6; %[W]
h.speedNr=(h.omega/red)*sqrt(h.Q/red);
h.Rratio=2*h.u_1red*h.c_u1red-h.c_u1red^2;
%--------------------------------------------------------------------------
% Filling in the outlet values and submerging in a table  
%--------------------------------------------------------------------------
h.i=h.i+1;  % Counts the number of rows in the table. Assigns the current values to the last row of table h.table_1. 
h.table_1(h.i,1)=h.u_1red; 
h.table_1(h.i,2)=h.Z_p1;    
h.table_1(h.i,3)=n;
h.table_1(h.i,4)=h.D_2;
h.table_1(h.i,5)=h.U_2;
h.table_1(h.i,6)=h.u_2red;
h.table_1(h.i,7)=h.c_m2;
h.table_1(h.i,8)=h.beta_2;
h.table_1(h.i,9)=h.D_1; 
h.table_1(h.i,10)=h.w_1;
h.table_1(h.i,11)=h.w_2;
h.table_1(h.i,12)=h.beta_1;
h.table_1(h.i,13)=h.acc;
h.table_1(h.i,14)=h.Hs;
h.table_1(h.i,15)=h.speedNr;
h.table_1(h.i,16)=h.Rratio;
h.table_n=h.table_1(end:-1:1,:); % Reverse table h.table_1 rowwise.(Last row of table h.table_1 first in table h.table_n)
set(h.CheckTable1,'Data',h.table_n);
%--------------------------------------------------------------------------
% Plot velocity trianlges
%--------------------------------------------------------------------------
try delete (h.VelocityAx);end
h.VelocityAx = axes('Position',[0.03 0.3 0.5 0.6],'Units','normalized',...
                    'Parent',main.panels(2),'box','on','Xtick',[-1 2],'Ytick',[-1 2]);    
inlet=[0.55 0.6];
outlet=[0.2 0.4];
scale1=0.7;
scale2=1;

h.cm1line=line([inlet(1) inlet(1)],[inlet(2)+h.c_m1red*scale1 inlet(2)]);axis([0 1 0 1])
h.c1line=line([inlet(1) inlet(1)-h.c_u1red*scale1],[inlet(2) inlet(2)+h.c_m1red*scale1]);
axis([0 1 0 1]);
h.w1line=line([inlet(1) inlet(1)+h.w_u1red*scale1],[inlet(2) inlet(2)+h.c_m1red*scale1]);
axis([0 1 0 1]);
h.u1line=line([inlet(1)-h.c_u1red*scale1 inlet(1)+h.w_u1red*scale1],...
    [inlet(2)+h.c_m1red*scale1 inlet(2)+h.c_m1red*scale1]);axis([0 1 0 1]);

%--------------------------------------------------------------------------
% plotting with fixed location of the upper left corner
%--------------------------------------------------------------------------
h.u2line=line([outlet(1)+h.table_n(1,5)/red*scale2 outlet(1)],[outlet(2) outlet(2)]);
axis([0 1 0 1]);
h.cm2line=line([outlet(1) outlet(1)],[outlet(2) outlet(2)-h.c_m2/red*scale2]);
axis([0 1 0 1]);
h.w2line=line([outlet(1)+h.table_n(1,5)/red*scale2 outlet(1)],...
    [outlet(2) outlet(2)-h.c_m2/red*scale2]);axis([0 1 0 1]);
%--------------------------------------------------------------------------
% Annotate the plot
%--------------------------------------------------------------------------
text(inlet(1)-h.c_u1red*scale1+0.01, inlet(2)+h.c_m1red*scale1+0.02,...
    ['\alpha_1 = ' num2str(h.alpha)],'FontSize',main.font-1,'Parent',h.VelocityAx);        %alpha1
text(((inlet(1)+h.w_u1red*scale1-0.05)-(inlet(1)-h.c_u1red*scale1+0.01))/2+0.1,...
    inlet(2)+h.c_m1red*scale1+0.02,['U_1 = ' num2str(h.u_1red)],'FontSize',main.font-1,...
    'Parent',h.VelocityAx);                                                                %U1
text(inlet(1)+h.w_u1red*scale1-0.05, inlet(2)+h.c_m1red*scale1+0.02,...
    ['\beta_1 = ' num2str(h.beta_1)],'FontSize',main.font-1,'Parent',h.VelocityAx);        %beta1
text(inlet(1)-0.03, inlet(2)+h.c_m1red*scale1*2/3,...
    ['C_{m1} = ' num2str(h.c_m1red)],'FontSize',main.font-1,'Parent',h.VelocityAx);        %Cm1
text(inlet(1)-h.c_u1red*scale1+0.01/2, inlet(2)+h.c_m1red*scale1/3,...
    ['C_1 = ' num2str(h.c_1red)],'FontSize',main.font-1,'Parent',h.VelocityAx);            %C1
text(inlet(1)+h.w_u1red*scale1-0.01/2, inlet(2)+h.c_m1red*scale1/5,...
    ['W_1 = ' num2str(h.w_1red)],'FontSize',main.font-1,'Parent',h.VelocityAx);            %W1

text(outlet(1)+0.01, outlet(2)+0.02,['U_2 = ' num2str(h.u_2red)],'FontSize',main.font-1,...
    'Parent',h.VelocityAx);                                                                 %U2
text(outlet(1)+h.u_2red*scale2-0.05, outlet(2)+0.02,['\beta_2 = ' num2str(h.beta_2)],...
    'FontSize',main.font-1,'Parent',h.VelocityAx);                                         %beta2
text(outlet(1)+h.u_2red*scale2-0.15, outlet(2)-0.1,['W_2 = ' num2str(h.w_2red)],...
    'FontSize',main.font-1,'Parent',h.VelocityAx);                                         %W1
text(outlet(1)-0.04, outlet(2)-0.07,['C_{m2} = ' num2str(h.c_m2red)],'FontSize',main.font-1,...
    'Parent',h.VelocityAx);                                                                 %Cm2 
end