function calcAV
disp('calcAV')

global g saved k
%--------------------------------------------------------------------------
% Get user inout values and set inital values
%--------------------------------------------------------------------------
g.ns=get(g.nsSlider,'Value');
g.ptemp=50;
g.Zmat=zeros(g.ptemp,g.ns);
g.Rmat=g.Zmat;
g.XY100=func_BezierCurve(g.shroud, 100);
g.XY=func_DistributeEvenly(g.XY100, g.ptemp);
g.Rmat(:,1)=g.XY(:,1);
g.Zmat(:,1)=g.XY(:,2);
%--------------------------------------------------------------------------
% Boundary conditions at inlet; straight inlet, streamlines equally
% spaced
%--------------------------------------------------------------------------
g.Rmat(1,:)=g.Rmat(1,1);
for L = 2:g.ns 
    g.Zmat(1,L)=g.Zmat(1,1)+saved.B_1*((L-1)/(g.ns-1));
end
%--------------------------------------------------------------------------
% Calculate outlet are without taking blade thickness into account, 
% will cause a minor numerical error
%--------------------------------------------------------------------------
Aout=pi*(saved.D_2/2)^2;
Asl=Aout/(g.ns-1);
%--------------------------------------------------------------------------
% Calculating the rest of the streamlines and distributing points along them
%--------------------------------------------------------------------------
for L = 2:g.ns-1
    for P = 2:g.ptemp-1;                    
        dy = g.Zmat(P-1,L-1)-g.Zmat(P+1,L-1);
        dx = g.Rmat(P-1,L-1)-g.Rmat(P+1,L-1);
        theta=abs(atan(dy/dx));
        Asec = (g.A_1-(g.A_1-g.A_2)*((P-1)/(g.ptemp-1)))/(g.ns-1);
        g.Rmat(P,L)=sqrt(g.Rmat(P,L-1)^2-Asec*sin(theta)/pi);
        g.Zmat(P,L)=g.Zmat(P,L-1)-(g.Rmat(P,L)-g.Rmat(P,L-1))*cos(theta)/sin(theta);
    end
    %   adding a help point to be able to distribute points for the next
    %   streamline
    P=g.ptemp;
    g.Rmat(P,L)=sqrt(g.Rmat(P,L-1)^2-Asl/pi);
    g.Zmat(P,L)=g.Zmat(P,1);
end
for L=g.ns
    for P = 2:g.ptemp-1;                    
        dy = g.Zmat(P-1,L-1)-g.Zmat(P+1,L-1);
        dx = g.Rmat(P-1,L-1)-g.Rmat(P+1,L-1);
        theta=abs(atan(dy/dx));
        Asec = (g.A_1-(g.A_1-g.A_2)*((P-1)/(g.ptemp-1)))/(g.ns-1);
        g.Rmat(P,L)=sqrt(g.Rmat(P,L-1)^2-Asec*sin(theta)/pi);
        g.Zmat(P,L)=g.Zmat(P,L-1)-(g.Rmat(P,L)-g.Rmat(P,L-1))*cos(theta)/sin(theta);
    end
    P=g.ptemp;
    g.Rmat(P,L)=0.0005;   % Need a small value instead of zero.
    g.Zmat(P,L)=g.Zmat(P,1);
end
%--------------------------------------------------------------------------
% Calculating the C_m velocity component in each point.
% Assuming the decrease in area is linear, the increase in c_m is linear too. 
%--------------------------------------------------------------------------
g.c_mMat=zeros(g.ptemp,g.ns);
g.c_mMat(1,:)=saved.c_m1;
dcm=saved.c_m2-saved.c_m1;
for P=2:g.ptemp
    g.c_mMat(P,:)=g.c_mMat(P-1,:)+dcm./((g.ptemp)-1);
end
%--------------------------------------------------------------------------
% Matrixes for hub and shroud exported to give geometry for CAD program
%--------------------------------------------------------------------------
g.HubXmat=g.Rmat(:,end);
g.HubYmat=zeros(size(g.HubXmat));
g.HubZmat=g.Zmat(:,end);
g.ShroudXmat=g.Rmat(:,1);
g.ShroudYmat=zeros(size(g.HubXmat));
g.ShroudZmat=g.Zmat(:,1);
try delete(g.Hub); end
g.Hub(:,1)=g.Rmat(:,end);
hubx=g.Hub(:,1);
g.Hub(:,2)=zeros(size(hubx));
g.Hub(:,3)=g.Zmat(:,end);
intstep=1000;
%--------------------------------------------------------------------------
% interpolate to have 1000 points on each streamline
%--------------------------------------------------------------------------
Rint=zeros(intstep,L);
Zint=zeros(intstep,L);
Cmint=zeros(intstep,L);
for L=1:g.ns
    R=linspace(g.Rmat(1,L),g.Rmat(end,L),intstep);
    Rint(:,L)=R';
    Z=interp1(g.Rmat(:,L),g.Zmat(:,L),R);
    Zint(:,L)=Z';
    Cm=interp1(g.Rmat(:,L),g.c_mMat(:,L),R);
    Cmint(:,L)=Cm';
end

if saved.av==0
    g.po0=[g.Rmat(end,1), g.Zmat(end,1)];
    g.po3=[g.Rmat(end-4,end), g.Zmat(end-4,end)];  
    g.po1=[g.Rmat(end,1)-(g.Rmat(end,1)-g.Rmat(end-4,end))/3,g.Zmat(end,1)-(g.Zmat(end,1)-g.Zmat(end-4,end))/3];
    g.po2=[g.Rmat(end,1)-2*(g.Rmat(end,1)-g.Rmat(end-4,end))/3,g.Zmat(end,1)-2*(g.Zmat(end,1)-g.Zmat(end-4,end))/3];   
    g.outlet=[g.po0; g.po1; g.po2; g.po3];
    g.tempo=g.outlet;
    g.outletinit=g.outlet;
    g.i=1;
else
    g.po0=[g.Rmat(end,1), g.Zmat(end,1)];
    g.po3=[g.Rmat(end-4,end), g.Zmat(end-4,end)];  
    g.po1=[g.Rmat(end,1)-(g.Rmat(end,1)-g.Rmat(end-4,end))/3,g.Zmat(end,1)-(g.Zmat(end,1)-g.Zmat(end-4,end))/3];
    g.po2=[g.Rmat(end,1)-2*(g.Rmat(end,1)-g.Rmat(end-4,end))/3,g.Zmat(end,1)-2*(g.Zmat(end,1)-g.Zmat(end-4,end))/3];   
    g.outletinit=[g.po0; g.po1; g.po2; g.po3];
    g.i=1;
end

g.outletLine=func_BezierCurve(g.outlet, 100);   % 100 points on the line 
    set(g.t1xStatic,'String',g.outlet(1,1));
    set(g.t1yStatic,'String',g.outlet(1,2));
    set(g.t2xEdit,'String',g.outlet(2,1));
    set(g.t2yEdit,'String',g.outlet(2,2));
    set(g.t3xEdit,'String',g.outlet(3,1));
    set(g.t3yEdit,'String',g.outlet(3,2));
    set(g.t4xEdit,'String',g.outlet(4,1));
    set(g.t4yEdit,'String',g.outlet(4,2));
%--------------------------------------------------------------------------
% Finding the intersection between the outlet line and the streamlines
%--------------------------------------------------------------------------
for L=1:g.ns
    g.delta=zeros(intstep,size(g.outletLine,1));
    for Out=1:size(g.outletLine,1)
        for P=1:intstep
            g.delta(P,Out)=sqrt((Rint(P,L)-g.outletLine(Out,1))^2+(Zint(P,L)-g.outletLine(Out,2))^2);
        end
    end
    i=find(g.delta==min(min(g.delta)),1);
    g.Rend(L)=mod(i,size(g.delta,1));
    if mod(i,size(g.delta,1))==0
       g.Rend(L)= intstep;
    end
    g.Out(L)=ceil(i/size(g.delta,1));
    clear g.delta
end
%--------------------------------------------------------------------------
% Redistributing to have 20 points in each streamline
%--------------------------------------------------------------------------
g.p=20;
Rtemp=zeros(g.p,g.ns);
Ztemp=Rtemp;
Cmtemp=Rtemp;
for L = 1:g.ns
    L_sl=0;
        for P = 2:g.Rend(L)                  
            L_sl=L_sl+sqrt((Rint(P,L)-Rint(P-1,L))^2+(Zint(P,L)-Zint(P-1,L))^2);
        end
    dL_sl=L_sl/(g.p-1);
   
    Li=0;
    j=1;
        for i=2:g.Rend(L) 
            Li=Li+sqrt((Rint(i,L)-Rint(i-1,L))^2+(Zint(i,L)-Zint(i-1,L))^2);
            if Li>j*dL_sl
                Rtemp(j+1,L)=Rint(i,L);
                Ztemp(j+1,L)=Zint(i,L);
                Cmtemp(j+1,L)=Cmint(i,L);
                j=j+1;
            end
        end
    Rtemp(end,L)=Rint(g.Rend(L),L);
    Ztemp(end,L)=Zint(g.Rend(L),L);
    Cmtemp(end,L)=Cmint(g.Rend(L),L);
end
Rtemp(1,:)=g.Rmat(1,:);
Ztemp(1,:)=g.Zmat(1,:);
Cmtemp(1,:)=g.c_mMat(1,:);
g.Rmat=Rtemp;
g.Zmat=Ztemp;
g.c_mMat=Cmtemp;
end