function calcSV
disp('calcSV')
global d h g b
% b.Z_sv=b.Z_gv;
b.Z_sv = str2double(get(b.Z_svEdit,'String'));
b.B_sv=b.B_gvout;
%--------------------------------------------------------------------------
% Outlet dimensions
%--------------------------------------------------------------------------
b.D_svout=b.D_gvin*1.03;
b.R_svout=b.D_svout/2;
b.c_usvout=b.c_ugvin*b.D_gvin/b.D_svout;
b.c_msvout=h.Q/(b.B_sv*pi*b.D_svout);
b.alpha_svout=atand(b.c_msvout/b.c_usvout);
%--------------------------------------------------------------------------
% Inlet Dimensions
%--------------------------------------------------------------------------
b.c_msvin=h.Q/(b.D_svin*b.B_sv*pi); %b.D_svin is a guess
b.c_usvin=b.c_usvout*(b.D_svout/b.D_svin);
b.alpha_svin=atand(b.c_msvin/b.c_usvin);
b.R_svin=b.D_svin/2;     %stay vane radius 
%--------------------------------------------------------------------------
% Free vortex constant
%--------------------------------------------------------------------------
b.C_t=b.c_usvin*b.R_svin; 
imax=50;
b.R_sv=zeros(1,imax);
b.alpha_sv=b.R_sv;
b.theta_sv=b.R_sv;
b.L_sv=b.R_sv;
b.angleBsv=b.R_sv;
b.c_usv=b.R_sv;
b.c_msv=b.R_sv;
b.c_usv(1)=b.c_usvout;
b.c_msv(1)=b.c_msvout;
b.dR=(b.R_svin-b.R_svout)/(imax-1);
b.R_sv(1)=b.R_svout;
b.theta_sv(1)=0;
b.alpha_sv(1)=b.alpha_svout;
b.L_sv(1)=0;
b.angleBsv(1)=0;
for i=2:imax
    b.R_sv(i)=b.R_sv(i-1)+b.dR;
    b.c_usv(i)=b.C_t/b.R_sv(i);
    b.c_msv(i)=h.Q/(2*pi*b.R_sv(i)*b.B_sv);
    b.alpha_sv(i)=atand(b.c_msv(i)/b.c_usv(i));
    b.angleBsv(i)=asind(b.R_sv(i-1)/b.R_sv(i)*sind(b.alpha_sv(i-1)+90));
    b.theta_sv(i)=b.theta_sv(i-1)+180-(b.angleBsv(i)+b.alpha_sv(i-1)+90);
    b.L_sv(i)=b.L_sv(i-1)+(b.R_sv(i-1)*sind(b.theta_sv(i)-b.theta_sv(i-1))/sind(b.angleBsv(i)));
end
b.theta_sv=-(max(b.theta_sv)-b.theta_sv);
[xsv, ysv]=pol2cart((b.theta_sv)*pi/180, b.R_sv);
%--------------------------------------------------------------------------
% Exporting for ProE
%--------------------------------------------------------------------------
d.xsvproE=xsv;
d.ysvproE=ysv;
%--------------------------------------------------------------------------
% Add thickness to stay vanes
%--------------------------------------------------------------------------
t_sv=str2double(get(b.t_svEdit,'String'))/1000;
d.tsvproE=t_sv;
dt=t_sv/2;
xtemp=zeros(length(xsv),2);
ytemp=xtemp;
for i=1:length(xsv)-1      
        dx = xsv(i)-xsv(i+1);
        dy = ysv(i)-ysv(i+1);
        Lvect2=sqrt(dx^2+dy^2);
        xtemp(i,1)=xsv(i)+dy*dt/Lvect2;
        xtemp(i,2)=xsv(i)-dy*dt/Lvect2;
        ytemp(i,1)=ysv(i)-dx*dt/Lvect2;
        ytemp(i,2)=ysv(i)+dx*dt/Lvect2;
end  
i=length(xsv);
        dx = xsv(i)-xsv(i-1);
        dy = ysv(i)-ysv(i-1);
        Lvect2=sqrt(dx^2+dy^2);
        xtemp(i,1)=xsv(i)-dy*dt/Lvect2;
        xtemp(i,2)=xsv(i)+dy*dt/Lvect2;
        ytemp(i,1)=ysv(i)+dx*dt/Lvect2;
        ytemp(i,2)=ysv(i)-dx*dt/Lvect2;
%--------------------------------------------------------------------------
% matrix of stay vanes to be defined from inlet to outlet.       
%--------------------------------------------------------------------------
d.svX(:,1,1)=xtemp(end:-1:1,1);
d.svY(:,1,1)=ytemp(end:-1:1,1);
d.svX(:,1,2)=xtemp(end:-1:1,2);
d.svY(:,1,2)=ytemp(end:-1:1,2);
%--------------------------------------------------------------------------
% Run function leadingsv to find leading edge of stay vanes. Method given
% by Ole is used, thus Xle, Yle contains a lot of helping points.
%--------------------------------------------------------------------------
[Xle, Yle]=leadingsv(t_sv, d.svX, d.svY);
%--------------------------------------------------------------------------
% leading edge profile of pressure and suction side given by listed points 
% in vectors XLEp, YLEp anf XLEs, YLEs
%--------------------------------------------------------------------------
d.XLEp=[Xle(3,:);Xle(17,:);Xle(18,:);Xle(19,:);Xle(20,:);Xle(21,:);Xle(22,:);Xle(23,:)];
d.YLEp=[Yle(3,:);Yle(17,:);Yle(18,:);Yle(19,:);Yle(20,:);Yle(21,:);Yle(22,:);Yle(23,:)];
d.XLEs=[Xle(26,:);Xle(40,:);Xle(41,:);Xle(42,:);Xle(43,:);Xle(44,:);Xle(45,:);Xle(46,:)];
d.YLEs=[Yle(26,:);Yle(40,:);Yle(41,:);Yle(42,:);Yle(43,:);Yle(44,:);Yle(45,:);Yle(46,:)];
%--------------------------------------------------------------------------
% Finding cross section of leading edge profile and side lines, d.svX, d.svY
%--------------------------------------------------------------------------
Lsvp=0;
i_le=1;
while Lsvp<t_sv/2
    Lsvp=Lsvp+sqrt((d.svX(i_le+1,1,1)-d.svX(i_le,1,1))^2+(d.svY(i_le+1,1,1)-d.svY(i_le,1,1))^2);
    i_le=i_le+1;
    if i_le>49
        break
    end
end
Lsvs=0;
j_le=1;
while Lsvs<t_sv/2
    Lsvs=Lsvs+sqrt((d.svX(j_le+1,1,2)-d.svX(j_le,1,2))^2+(d.svY(j_le+1,1,2)-d.svY(j_le,1,2))^2);
    j_le=j_le+1;
        if j_le>49
            break
    end
end
[Xte, Yte]=trailingsv(t_sv, d.svX, d.svY);
d.XTE=[Xte(9:-1:6,1); Xte(1,1)];
d.YTE=[Yte(9:-1:6,1); Yte(1,1)];
L_svps=0;
for i=2:d.index_svps
    L_svps=L_svps+sqrt((d.xnewps(i)-d.xnewps(i-1))^2+(d.ynewps(i)-d.ynewps(i-1))^2);
end
i_te=1;
Lsvps=0;
while Lsvps<L_svps
    i_te=i_te+1;
    Lsvps=Lsvps+sqrt((d.svX(i_te,1,1)-d.svX(i_te-1,1,1))^2+(d.svY(i_te,1,1)-d.svY(i_te-1,1,1))^2);
end
d.svXp=[d.XLEp;d.svX(i_le:i_te-1,1,1);d.XTE;d.svX(end,1,2)];
d.svYp=[d.YLEp;d.svY(i_le:i_te-1,1,1);d.YTE;d.svY(end,1,2)];
d.svXs=[d.XLEs;d.svX(j_le:end,1,2)];
d.svYs=[d.YLEs;d.svY(j_le:end,1,2)];
d.stayvaneX=[d.svXp(end:-1:1);d.svXs];
d.stayvaneY=[d.svYp(end:-1:1);d.svYs];
for i=2:5
    d.stayvaneX(:,i)=d.stayvaneX(:,1);
    d.stayvaneY(:,i)=d.stayvaneY(:,1);
end
%--------------------------------------------------------------------------
% Make matrix for stay vanes to have 3D profile
%--------------------------------------------------------------------------
dz=b.B_sv;
d.stayvaneZ=zeros(size(d.stayvaneX));
for i=1:5
d.stayvaneZ(:,i)=g.HubZmat(1,1)+0.0005-dz*(i-1)/4;
end
i_sv=0;
set(gcf,'CurrentAxes', b.gvFig)
try delete(b.svplot); end
b.svplot=0;
hold on
for angle=0:2*pi/b.Z_sv:2*pi
        i_sv=i_sv+1;
        [theta r]=cart2pol(d.stayvaneX(:,1), d.stayvaneY(:,1));
        theta=theta+angle;
        [xsvplot ysvplot]=pol2cart(theta,r);
        b.svplot(i_sv)=plot(xsvplot,ysvplot,'r-');       
end
axis equal
%plotting inner stay vane limit
try delete(b.svoutplot); end
b.svoutplot=0;
hold on
Radiussvout = b.D_svout/2;
[x,y,~] = cylinder(Radiussvout,200);
b.svoutplot=plot(x(1,:),y(1,:),'r-','linewidth',1);
%plotting outer stay vane limit
try delete(b.svinplot); end
b.svinplot=0;
hold on
gvRadius = b.D_svin/2;
[x,y,~] = cylinder(gvRadius,200);
b.svinplot=plot(x(1,:),y(1,:),'r-','linewidth',1);

b.DTable(1,1)=b.axislocation;
b.DTable(2,1)=b.D_gvout;
b.DTable(3,1)=b.D_gvax;
b.DTable(4,1)=b.D_gvin;
b.DTable(5,1)=b.D_svout;
b.DTable(6,1)=b.D_svin;
b.DTable(7,1)=b.L_gv;
b.DTable(8,1)=b.L_sv(end);
set(b.DiameterTable,'Data',b.DTable);
end